pub enum Grouping {
Ungrouped,
Invisible,
Parens,
}Expand description
Whether an expansion should be surrounded by a None-delimited Group
Ord is valid for composition with cmp::max
Variants
Implementations
Sourceimpl Grouping
impl Grouping
Sourcepub fn surround(&self, none_span: Span, ts: impl ToTokens) -> TokenStream
pub fn surround(&self, none_span: Span, ts: impl ToTokens) -> TokenStream
Surround ts as specified by this Grouping
none_span is the span to use for None-delimiters.
It should generally be the principal span of the contained thing,
whatever that is. For a type, that’s the primary ident.