pub fn respan_hygiene(input: TokenStream, span: Span) -> TokenStreamExpand description
Respan the resolution hygiene of all identifiers to span
pub fn respan_hygiene(input: TokenStream, span: Span) -> TokenStreamRespan the resolution hygiene of all identifiers to span