pub struct ErrorAccumulator {
bad: Option<Error>,
defused: bool,
}Expand description
Contains zero or more syn::Error
Panics
Panics if dropped.
You must call one of the consuming methods, eg finish
Fields
bad: Option<Error>defused: boolImplementations
Sourceimpl ErrorAccumulator
impl ErrorAccumulator
Sourcepub fn handle_in<T, F>(&mut self, f: F) -> Option<T>
pub fn handle_in<T, F>(&mut self, f: F) -> Option<T>
Run f, accumulate any error, and return an Ok
Sourcepub fn handle<T>(&mut self, result: Result<T>) -> Option<T>
pub fn handle<T>(&mut self, result: Result<T>) -> Option<T>
Handle a Result: accumulate any error, and returni an Ok
Sourcepub fn finish(self) -> Result<()>
pub fn finish(self) -> Result<()>
If there were any errors, return a single error that combines them
Sourcepub fn finish_with<T>(self, success: T) -> Result<T>
pub fn finish_with<T>(self, success: T) -> Result<T>
If there were any errors, return Err, otherwise Ok(success)
Sourcepub fn into_inner(self) -> Option<Error>
pub fn into_inner(self) -> Option<Error>
If there any errors, return a single error that combines them