pub struct IdentAny(pub Ident);Expand description
Like syn::Ident but parses using parse_any, accepting keywords
Used for derive-deftly’s own keywords, which can be Rust keywords, or identifiers.
Needs care when used with user data, since it might be a keyword, in which case it’s not really an identifier.
Tuple Fields
0: IdentTrait Implementations
Sourceimpl ToTokens for IdentAny
impl ToTokens for IdentAny
Sourcefn to_tokens(&self, out: &mut TokenStream)
fn to_tokens(&self, out: &mut TokenStream)
Sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
Sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere
Self: Sized,