pub fn engine_macro_name() -> Result<TokenStream, Error>Expand description
Return a full path to the location of derive_deftly_engine.
(This may not work properly if the user imports the crate under a different name. This is a problem with the way cargo and rustc handle imports and proc-macro crates, which I think we can’t properly solve here.)