pub trait ToTokensPunctComposable {
// Required method
fn to_tokens_punct_composable(&self, out: &mut TokenStream);
}Expand description
Convert to a token stream in a way that composes nicely
Required Methods
fn to_tokens_punct_composable(&self, out: &mut TokenStream)
Implementations on Foreign Types
Sourceimpl<P> ToTokensPunctComposable for Option<&&P>
Ensure that something is output, for punctuation P
impl<P> ToTokensPunctComposable for Option<&&P>
Ensure that something is output, for punctuation P
Implemented for Option<&&P> because that’s what you get from
Punctuated::pairs().next().punct().
fn to_tokens_punct_composable(&self, out: &mut TokenStream)
Implementors
impl<T, P> ToTokensPunctComposable for Punctuated<T, P>
Ensure that there is a trailing punctuation if needed